function [critval] = deandixon_crit(n, p)
    // Returns the critical Q value for Dean-Dixon test.
    //
    // Parameter
    // n: number of numerical values
    // p: statistical confidence level (%) as a string or the level of significance (alpha) as a decimal value, "95%", "99%", "99.9%" or 0.05, 0.01, 0.001 resp.
    
    
    
    // qtable contains the critical values critval for N (number of values)
    // and alpha (niveau of significance)  
    // Column 1 : Number of values (N)
    // Column 2 : Q_crit, 95% confidence level, alpha = 0.05
    // Column 3 : Q_crit, 99% confidence level, alpha = 0.01
    // Column 4 : Q_crit, 99.9% confidence level, alpha = 0.001
    qtable = [ ...
    3 0.941 0.994 0.999; ...
    4 0.766 0.921 0.964; ...
    5 0.643 0.824 0.895; ...
    6 0.563 0.744 0.822; ...
    7 0.507 0.681 0.763; ...
    8 0.467 0.633 0.716; ...
    9 0.436 0.596 0.675; ...
    10 0.412 0.568 0.647; ...
    15 0.338 0.473 0.544; ...
    20 0.300 0.426 0.491; ...
    25 0.277 0.395 0.455; ...
    30 0.260 0.371 0.430  ...
    ];

    // Set the proper column of the t-table, depending on confidence level
    select(p)
    case("95%")
        j = 2;
    case(0.05)
        j = 2;
    case("99%")
        j = 3;
    case(0.01)
        j = 3;
    case("99.9%")
        j = 4;
    case(0.001)
        j = 4;
    else
        error("Wrong confidence level");
    end

    // Pick the appropriate Q_crit value, interpolate if necessary
    if (n >= 3 & n <= 10)
        critval = qtable(n-2,j);
    elseif (n >= 11  & n <= 29)
        i = 6 + floor(n/5); // Determine row, 6=correction factor
        qs = (qtable(i,j) - qtable(i+1,j))/5;
        mul = n - qtable(i,1); // Multiplicator for qs
        critval = qtable(i,j) - (mul * qs);
        //    critval = qtable(i,j) - ((qtable(i,j)-qtable(i+1,j))/5);
    else // for the last value (30)
        i = 6 + floor(n/5); // Determine row, 6=correction factor
        critval = qtable(i,j);
    end
    return;
    endfunction
